%MATLAB version of the script for algorithm 8.2 on pages 365 of conte/deboor
% Program to solve the first order differential equation
%   Y'(X) = F(X,Y)
% with initial condition of
%   Y(XBEGIN) = YBEGIN
% to the point  XEND , using the second-order Runge-Kutta method.
% This is Example 8.2
F = @(x,y) (1./x - y)./x - y.*y;

disp(' Method 2 -- Simplified Runge-Kutta order 2')
disp(['  H                Y(1.5)           YPRIM(1.5)       Y(2)  ', ...
      '           YPRIM(2)'])
for NSTEPS=2.^(4:7)
   RK2(F,1,-1,2,NSTEPS)
end

function RK2(F, XBEGIN, YBEGIN, XEND, NSTEPS)
H = (XEND - XBEGIN)/NSTEPS; XN = XBEGIN; YN = YBEGIN;  DERIV = F(XN,YN);
N = 0;
% fprintf(' %15.8e  %15.8e  %15.8e  %15.8e\n',[H,XN,YN,DERIV])
count = 1;
for N=1:NSTEPS
   k1 = H*F(XN,YN); k2 = H*F(XN+H,YN+k1); 
   YN = YN + (k1+k2)/2; XN = XN+H; DERIV = F(XN,YN);
   if XN==1.5
      out1p5 = [H,YN,DERIV];
   elseif XN==2
      fprintf(' %15.8e  %15.8e  %15.8e  %15.8e  %15.8e\n',[out1p5,YN,DERIV])
   end
end
return, end
